<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

if ( ! function_exists( 'yummy_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'yummy_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'yummy_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'yummy_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'yummy_pro_is_slider_enable' ) ) :
	/**
	 * Check if slider is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_enable( $control ) {
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_slider]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_slider_demo_and_post_disable' ) ) :
	/**
	 * Check if slider content type demo and post is disabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_demo_and_post_disable( $control ) {
		$slider_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[slider_content_type]' )->value();
		if ( ( yummy_pro_is_slider_enable( $control ) ) && ( ( 'demo' != $slider_content_type ) && ( 'post' != $slider_content_type ) ) ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_slider_demo_disable' ) ) :
	/**
	 * Check if slider content type demo is disabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_demo_disable( $control ) {
		$slider_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[slider_content_type]' )->value();
		if ( ( yummy_pro_is_slider_enable( $control ) ) && ( 'demo' != $slider_content_type ) ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_slider_content_type_page_enable' ) ) :
	/**
	 * Check if slider content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_content_type_page_enable( $control ) {
		$slider_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[slider_content_type]' )->value();
		if ( yummy_pro_is_slider_enable( $control ) && 'page' == $slider_content_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_is_slider_content_type_category_enable' ) ) :
	/**
	 * Check if slider content type category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_content_type_category_enable( $control ) {
		$slider_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[slider_content_type]' )->value();
		if ( yummy_pro_is_slider_enable( $control ) && 'category' == $slider_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_slider_content_type_post_enable' ) ) :
	/**
	 * Check if slider content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_slider_content_type_post_enable( $control ) {
		$slider_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[slider_content_type]' )->value();
		if ( yummy_pro_is_slider_enable( $control ) && 'post' == $slider_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_enable' ) ) :
	/**
	 * Check if about is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_enable( $control ) {
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_about]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_content_type_page_enable' ) ) :
	/**
	 * Check if about content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_content_type_page_enable( $control ) {
		$about_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_content_type]' )->value();
		if ( yummy_pro_is_about_enable( $control ) && 'page' == $about_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_content_type_post_enable' ) ) :
	/**
	 * Check if about content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_content_type_post_enable( $control ) {
		$about_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_content_type]' )->value();
		if ( yummy_pro_is_about_enable( $control ) && 'post' == $about_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_contact_form_active' ) ) :
	/**
	 * Check if contact form section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_contact_form_active( $control ) {		
		return ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_contact_form]' )->value() );
	}
endif;

if ( ! function_exists( 'yummy_pro_is_map_section_active' ) ) :
	/**
	 * Check if map section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_map_section_active( $control ) {		
		return ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_map]' )->value() );
	}
endif;

if ( ! function_exists( 'yummy_pro_is_special_item_section_active' ) ) :
	/**
	 * Check if special item section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_special_item_section_active( $control ) {		
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_special_item]' )->value() ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_special_item_header_custom' ) ) :
	/**
	 * Check if special item header content is custom.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_header_custom( $control ) {		
		$special_item_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_header_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'custom' == $special_item_header_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_special_item_header_page' ) ) :
	/**
	 * Check if special item header content is page.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_header_page( $control ) {		
		$special_item_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_header_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'page' == $special_item_header_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_special_item_content_post' ) ) :
	/**
	 * Check if special item content is post.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_content_post( $control ) {		
		$special_item_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_content_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'post' == $special_item_content_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_special_item_content_category' ) ) :
	/**
	 * Check if special item content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_content_category( $control ) {		
		$special_item_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_content_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'category' == $special_item_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_item_content_woo_product' ) ) :
	/**
	 * Check if special item content is woo product.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_content_woo_product( $control ) {		
		$special_item_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_content_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'woo-product' == $special_item_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_item_content_woo_category' ) ) :
	/**
	 * Check if special item content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_content_woo_category( $control ) {		
		$special_item_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_content_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'woo-category' == $special_item_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_item_content_count' ) ) :
	/**
	 * Check if special item content is category or woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_item_content_count( $control ) {		
		$special_item_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_item_content_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && ( 'woo-category' == $special_item_content_type || 'category' == $special_item_content_type ) ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_call_to_action_active' ) ) :
	/**
	 * Check if call to action section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_call_to_action_active( $control ) {		
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_call_to_action]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_slider_content_type_post_disable' ) ) :
	/**
	 * Check if about-us content type post is disabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_slider_content_type_post_disable( $control ) {
		$about_us_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_content_type]' )->value();
		if ( 'post' != $about_us_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_slider_content_type_page_enable' ) ) :
	/**
	 * Check if about-us content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_slider_content_type_page_enable( $control ) {
		$about_us_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_content_type]' )->value();
		if ( 'page' == $about_us_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_call_to_action_custom' ) ) :
	/**
	 * Check if call to action content is custom.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_call_to_action_custom( $control ) {		
		$call_to_action_type = $control->manager->get_setting( 'yummy_pro_theme_options[call_to_action_type]' )->value();
		if ( yummy_pro_is_call_to_action_active( $control ) && 'custom' == $call_to_action_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_slider_content_type_category_enable' ) ) :
	/**
	 * Check if about-us content type category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_slider_content_type_category_enable( $control ) {
		$about_us_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_content_type]' )->value();
		if ( 'category' == $about_us_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_slider_content_type_post_enable' ) ) :
	/**
	 * Check if about-us content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_slider_content_type_post_enable( $control ) {
		$about_us_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_content_type]' )->value();
		if ( 'post' == $about_us_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_call_to_action_page' ) ) :
	/**
	 * Check if call to action content is page.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_call_to_action_page( $control ) {		
		$call_to_action_type = $control->manager->get_setting( 'yummy_pro_theme_options[call_to_action_type]' )->value();
		if ( yummy_pro_is_call_to_action_active( $control ) && 'page' == $call_to_action_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_interior_content_type_page_enable' ) ) :
	/**
	 * Check if interior content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_interior_content_type_page_enable( $control ) {
		$about_us_interior_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_interior_content_type]' )->value();
		if ( 'page' == $about_us_interior_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_item_menu_active' ) ) :
	/**
	 * Check if special item menu section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_item_menu_active( $control ) {		
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_item_menu]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_item_menu_content_category' ) ) :
	/**
	 * Check if item menu content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_item_menu_content_category( $control ) {		
		$item_menu_type = $control->manager->get_setting( 'yummy_pro_theme_options[item_menu_type]' )->value();
		if ( yummy_pro_is_item_menu_active( $control ) && 'category' == $item_menu_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_item_menu_content_woo_category' ) ) :
	/**
	 * Check if item menu content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_item_menu_content_woo_category( $control ) {		
		$item_menu_type = $control->manager->get_setting( 'yummy_pro_theme_options[item_menu_type]' )->value();
		if ( yummy_pro_is_item_menu_active( $control ) && 'woo-category' == $item_menu_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_interior_content_type_post_enable' ) ) :
	/**
	 * Check if interior content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_interior_content_type_post_enable( $control ) {
		$about_us_interior_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_interior_content_type]' )->value();
		if ( 'post' == $about_us_interior_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_interior_content_type_custom_enable' ) ) :
	/**
	 * Check if interior content type custom is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_interior_content_type_custom_enable( $control ) {
		$about_us_interior_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_interior_content_type]' )->value();
		if ( 'custom' == $about_us_interior_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_special_day_section_active' ) ) :
	/**
	 * Check if special day section is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_special_day_section_active( $control ) {
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_special_day]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_left_type_custom' ) ) :
	/**
	 * Check if special day left note type is custom.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_left_type_custom( $control ) {
		$special_day_left_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_left_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'custom' == $special_day_left_type ) {
			return true;
		}
		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_special_day_right_count' ) ) :
	/**
	 * Check if special day right section content is category or woo category .
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_count( $control ) {		
		$special_day_right_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && ( 'woo-category' == $special_day_right_type || 'category' == $special_day_right_type ) ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_type_post' ) ) :
	/**
	 * Check if special day right type is post.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_type_post( $control ) {
		$special_day_right_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'post' == $special_day_right_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_type_category' ) ) :
	/**
	 * Check if special day right type is category.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_type_category( $control ) {
		$special_day_right_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'category' == $special_day_right_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_type_woo_product' ) ) :
	/**
	 * Check if special day right type is woo product.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_type_woo_product( $control ) {
		$special_day_right_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'woo-product' == $special_day_right_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_type_woo_category' ) ) :
	/**
	 * Check if special day right type is woo category.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_type_woo_category( $control ) {
		$special_day_right_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'woo-category' == $special_day_right_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_note_type_post' ) ) :
	/**
	 * Check if special day right note type is post.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_note_type_post( $control ) {
		$special_day_right_note_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_note_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'post' == $special_day_right_note_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_note_type_page' ) ) :
	/**
	 * Check if special day right note type is page.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_note_type_page( $control ) {
		$special_day_right_note_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_note_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'page' == $special_day_right_note_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_special_day_right_note_type_custom' ) ) :
	/**
	 * Check if special day right note type is custom.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_special_day_right_note_type_custom( $control ) {
		$special_day_right_note_type = $control->manager->get_setting( 'yummy_pro_theme_options[special_day_right_note_type]' )->value();
		if ( yummy_pro_is_special_day_section_active( $control ) && 'custom' == $special_day_right_note_type ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_recipe_enable' ) ) :
	/**
	 * Check if recipe section is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_recipe_enable( $control ) {
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_recipe]' )->value() ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_recipe_content_type_post_enable' ) ) :
	/**
	 * Check if recipe section content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_recipe_content_type_post_enable( $control ) {
		$recipe_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[recipe_content_type]' )->value();
		if ( yummy_pro_is_recipe_enable( $control ) && 'post' == $recipe_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_recipe_content_type_category_enable' ) ) :
	/**
	 * Check if recipe section content type category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_recipe_content_type_category_enable( $control ) {
		$recipe_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[recipe_content_type]' )->value();
		if ( yummy_pro_is_recipe_enable( $control ) && 'category' == $recipe_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_recipe_content_type_recipe_post_enable' ) ) :
	/**
	 * Check if recipe section content type tp-recipe post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_recipe_content_type_recipe_post_enable( $control ) {
		$recipe_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[recipe_content_type]' )->value();
		if ( yummy_pro_is_recipe_enable( $control ) && 'tp-recipe' == $recipe_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_recipe_content_type_recipe_category_enable' ) ) :
	/**
	 * Check if recipe section content type tp-recipe category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_recipe_content_type_recipe_category_enable( $control ) {
		$recipe_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[recipe_content_type]' )->value();
		if ( yummy_pro_is_recipe_enable( $control ) && 'tp-recipe-category' == $recipe_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_testimonial_section_active' ) ) :
	/**
	 * Check if testimonial section is active.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_testimonial_section_active( $control ) {
		if ( $control->manager->get_setting( 'yummy_pro_theme_options[enable_testimonial]' )->value() ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_testimonial_header_custom' ) ) :
	/**
	 * Check if testimonial header content is custom.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_testimonial_header_custom( $control ) {
		$testimonial_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[testimonial_header_type]' )->value();
		if ( yummy_pro_is_testimonial_section_active( $control ) && 'custom' == $testimonial_header_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_testimonial_header_page' ) ) :
	/**
	 * Check if testimonial header content is page.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_testimonial_header_page( $control ) {
		$testimonial_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[testimonial_header_type]' )->value();
		if ( yummy_pro_is_testimonial_section_active( $control ) && 'page' == $testimonial_header_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_testimonial_content_post' ) ) :
	/**
	 * Check if testimonial header content is post.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_testimonial_content_post( $control ) {
		$testimonial_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[testimonial_content_type]' )->value();
		if ( yummy_pro_is_testimonial_section_active( $control ) && 'post' == $testimonial_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_testimonial_content_testimonial_posts' ) ) :
	/**
	 * Check if testimonial content is testimonial Post.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_testimonial_content_testimonial_posts( $control ) {
		$testimonial_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[testimonial_content_type]' )->value();
		if ( yummy_pro_is_testimonial_section_active( $control ) && 'tp-philosophy-testi' == $testimonial_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_primary_menu_disable' ) ) :
	/**
	 * Check if menu is disabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_primary_menu_disable( $control ) {
		if ( 0 ==  $control->manager->get_setting( 'yummy_pro_theme_options[disable_primary_menu]' )->value() )  {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_team_advert_type_page_enable' ) ) :
	/**
	 * Check if about-advert content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_team_advert_type_page_enable( $control ) {
		$about_us_advert_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_advert_content_type]' )->value();
		if ( 'page' == $about_us_advert_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_team_advert_type_post_enable' ) ) :
	/**
	 * Check if about-advert content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_team_advert_type_post_enable( $control ) {
		$about_us_advert_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_advert_content_type]' )->value();
		if ( 'post' == $about_us_advert_content_type ){
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_team_content_type_post_enable' ) ) :
	/**
	 * Check if about-team content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_team_content_type_post_enable( $control ) {
		$about_us_team_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_team_content_type]' )->value();
		if ( 'post' == $about_us_team_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_about_us_team_content_type_tp_post_enable' ) ) :
	/**
	 * Check if about-team content type tp-philosophy post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_about_us_team_content_type_tp_post_enable( $control ) {
		$about_us_team_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_team_content_type]' )->value();
		if ( 'tp-philosophy-teams' == $about_us_team_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_team_content_category_enable' ) ) :
	/**
	 * Check if about-team-choice content type category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_team_content_category_enable( $control ) {
		$about_us_choice_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_choice_content_type]' )->value();
		if ( 'category' == $about_us_choice_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_team_content_tp_category_enable' ) ) :
	/**
	 * Check if about-team-choice content type tp-philosophy category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_team_content_tp_category_enable( $control ) {
		$about_us_choice_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_choice_content_type]' )->value();
		if ( 'tp-philosophy-teams-category' == $about_us_choice_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_team_content_woo_category_enable' ) ) :
	/**
	 * Check if about-team-choice content type woo-category is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_team_content_woo_category_enable( $control ) {
		$about_us_choice_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[about_us_choice_content_type]' )->value();
		if ( 'woo-category' == $about_us_choice_content_type ) {
			return true;
		}

		return false;
	}
endif;

//reservation section
if ( ! function_exists( 'yummy_pro_is_phone_reservation_type_post_enable' ) ) :
	/**
	 * Check if phone-reservation content type post is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_phone_reservation_type_post_enable( $control ) {
		$reservation_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[reservation_content_type]' )->value();
		if ( 'post' == $reservation_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_phone_reservation_type_page_enable' ) ) :
	/**
	 * Check if phone-reservation content type page is enabled.
	 *
	 * @since Yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_phone_reservation_type_page_enable( $control ) {
		$reservation_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[reservation_content_type]' )->value();
		if ( 'page' == $reservation_content_type ){
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_reservation_header_custom' ) ) :
	/**
	 * Check if reservation header content is custom.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_reservation_header_custom( $control ) {		
		$reservation_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[reservation_header_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'custom' == $reservation_header_type ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'yummy_pro_reservation_header_page' ) ) :
	/**
	 * Check if reservation header content is page.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_reservation_header_page( $control ) {		
		$reservation_header_type = $control->manager->get_setting( 'yummy_pro_theme_options[reservation_header_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'page' == $reservation_header_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_reservation_memorable_type_post_enable' ) ) :
	/**
	 * Check if reservation-memorable content is post.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_reservation_memorable_type_post_enable( $control ) {		
		$memorable_reservation_type = $control->manager->get_setting( 'yummy_pro_theme_options[memorable_reservation_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'post' == $memorable_reservation_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_reservation_memorable_type_category_enable' ) ) :
	/**
	 * Check if reservation-memorable content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_reservation_memorable_type_category_enable( $control ) {		
		$memorable_reservation_type = $control->manager->get_setting( 'yummy_pro_theme_options[memorable_reservation_type]' )->value();
		if ( yummy_pro_is_special_item_section_active( $control ) && 'category' == $memorable_reservation_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_first_section_content_category' ) ) :
	/**
	 * Check if menu page first section content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_first_section_content_category( $control ) {		
		$menu_first_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_first_section_content_type]' )->value();
		if ( 'category' == $menu_first_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_first_section_content_woo_category' ) ) :
	/**
	 * Check if menu page first section content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_first_section_content_woo_category( $control ) {		
		$menu_first_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_first_section_content_type]' )->value();
		if ( 'woo-category' == $menu_first_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_second_section_content_category' ) ) :
	/**
	 * Check if menu page second section content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_second_section_content_category( $control ) {		
		$menu_second_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_second_section_content_type]' )->value();
		if ( 'category' == $menu_second_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_second_section_content_woo_category' ) ) :
	/**
	 * Check if menu page second section content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_second_section_content_woo_category( $control ) {		
		$menu_second_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_second_section_content_type]' )->value();
		if ( 'woo-category' == $menu_second_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_third_section_content_category' ) ) :
	/**
	 * Check if menu page third section content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_third_section_content_category( $control ) {		
		$menu_third_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_third_section_content_type]' )->value();
		if ( 'category' == $menu_third_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_third_section_content_woo_category' ) ) :
	/**
	 * Check if menu page third section content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_third_section_content_woo_category( $control ) {		
		$menu_third_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_third_section_content_type]' )->value();
		if ( 'woo-category' == $menu_third_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_forth_section_content_category' ) ) :
	/**
	 * Check if menu page forth section content is category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_forth_section_content_category( $control ) {		
		$menu_forth_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_forth_section_content_type]' )->value();
		if ( 'category' == $menu_forth_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_forth_section_content_woo_category' ) ) :
	/**
	 * Check if menu page forth section content is woo category.
	 *
	 * @since yummy Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_forth_section_content_woo_category( $control ) {		
		$menu_forth_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_forth_section_content_type]' )->value();
		if ( 'woo-category' == $menu_forth_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_fifth_section_content_category' ) ) :
	/**
	 * Check if menu page fifth section content is category.
	 *
	 * @since yummy Pro 1.3
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_fifth_section_content_category( $control ) {		
		$menu_fifth_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_fifth_section_content_type]' )->value();
		if ( 'category' == $menu_fifth_section_content_type ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'yummy_pro_is_menu_fifth_section_content_woo_category' ) ) :
	/**
	 * Check if menu page fifth section content is woo category.
	 *
	 * @since yummy Pro 1.3
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yummy_pro_is_menu_fifth_section_content_woo_category( $control ) {		
		$menu_fifth_section_content_type = $control->manager->get_setting( 'yummy_pro_theme_options[menu_fifth_section_content_type]' )->value();
		if ( 'woo-category' == $menu_fifth_section_content_type ) {
			return true;
		}

		return false;
	}
endif;