<?php
/**
 * Recipe options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */
// Add slider section
$wp_customize->add_section( 'yummy_pro_recipe_section', array(
    'title'             => esc_html__( 'Recipe Section','yummy-pro' ),
    'description'       => esc_html__( 'Recipe options.', 'yummy-pro' ),
    'panel'             => 'yummy_pro_sections_panel',
) );
/**
 * Slider Options
 */
// Enable slider.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_recipe]', array(
    'default'           => $options['enable_recipe'],
    'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_recipe]', array(
    'label'             => esc_html__( 'Enable Recipe Section', 'yummy-pro' ),
    'section'           => 'yummy_pro_recipe_section',
    'type'              => 'checkbox',
) );

// Enable slider.
$wp_customize->add_setting( 'yummy_pro_theme_options[button_label]', array(
    'default'           => $options['button_label'],
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[button_label]', array(
    'label'             => esc_html__( 'Button Label', 'yummy-pro' ),
    'section'           => 'yummy_pro_recipe_section',
    'type'              => 'text',
    'active_callback'   => 'yummy_pro_is_recipe_enable',
) );

/**
 * Recipe content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[recipe_content_type]', array(
    'default'           => $options['recipe_content_type'],
    'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[recipe_content_type]', array(
    'active_callback'   => 'yummy_pro_is_recipe_enable',
    'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
    'section'           => 'yummy_pro_recipe_section',
    'choices'           => yummy_pro_recipe_content_type_options(),
    'type'              => 'select',
) );

/**
 * Post Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[recipe_post_ids]', array(
    'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[recipe_post_ids]', array(
    'active_callback'   => 'yummy_pro_is_recipe_content_type_post_enable',
    'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
    'description'       => esc_html__( 'Max. posts allowed is 4. ie: 11, 24, 34', 'yummy-pro' ),
    'section'           => 'yummy_pro_recipe_section',
    'type'              => 'text',
) );

// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[recipe_category]', array(
    'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[recipe_category]', array(
    'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
    'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
    'section'         => 'yummy_pro_recipe_section',
    'type'            => 'dropdown-category',
    'active_callback' => 'yummy_pro_is_recipe_content_type_category_enable',
) ) );

if( class_exists( 'TP_Recipe' ) ) {
    /**
     * Post Content Type Options
     */
    $wp_customize->add_setting( 'yummy_pro_theme_options[recipe_post_recipe_ids]', array(
        'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
    ) );

    $wp_customize->add_control( 'yummy_pro_theme_options[recipe_post_recipe_ids]', array(
        'active_callback'   => 'yummy_pro_is_recipe_content_type_recipe_post_enable',
        'label'             => esc_html__( 'Input Recipe Post Ids', 'yummy-pro' ),
        'description'       => esc_html__( 'Max. posts allowed is 4. ie: 11, 24, 34', 'yummy-pro' ),
        'section'           => 'yummy_pro_recipe_section',
        'type'              => 'text',
    ) );

    // Show category type setting and control
    $wp_customize->add_setting( 'yummy_pro_theme_options[tp_recipe_category]', array(
        'sanitize_callback' => 'absint'
    ) );

    $wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[tp_recipe_category]', array(
        'label'           => esc_html__( 'Select Recipe Category', 'yummy-pro' ),
        'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
        'section'         => 'yummy_pro_recipe_section',
        'taxonomy'        => 'tp-recipe-category',
        'type'            => 'dropdown-category',
        'active_callback' => 'yummy_pro_is_recipe_content_type_recipe_category_enable',
    ) ) );
}